@@ -79,7 +79,8 @@
 #'   missing values are preserved, so the return value has the same length /
 #'   number of rows as the original input.
 #'
-#' @seealso See [center()] for grand-mean centering of variables.
+#' @seealso See [center()] for grand-mean centering of variables, and
+#'   [makepredictcall.dw_transformer()] for use in model formulas.
 #'
 #' @family transform utilities
 #' @family standardize
@@ -148,6 +149,17 @@ standardize.numeric <- function(x,
                                 scale = NULL,
                                 verbose = TRUE,
                                 ...) {
+  # set default - need to fix this, else we don't know whether this
+  # comes from "center()" or "standardize()". Furthermore, data.frame
+  # methods cannot return a vector of NULLs for each variable - instead
+  # they return NA. Thus, we have to treat NA like NULL
+  if (is.null(scale) || is.na(scale)) {
+    scale <- TRUE
+  }
+  if (is.null(center) || is.na(center)) {
+    center <- TRUE
+  }
+
   args <- .process_std_center(x, weights, robust, verbose, reference, center, scale)
 
   # Perform standardization
@@ -170,7 +182,9 @@ standardize.numeric <- function(x,
   attr(scaled_x, "scale") <- args$scale
   attr(scaled_x, "robust") <- robust
   # labels
-  .set_back_labels(scaled_x, x, include_values = FALSE)
+  z <- .set_back_labels(scaled_x, x, include_values = FALSE)
+  class(z) <- c("dw_transformer", class(z))
+  z
 }
 
 #' @export
@@ -191,6 +205,7 @@ standardize.matrix <- function(x, ...) {
   attr(x_out, "center") <- sapply(xz, attr, "center")
   attr(x_out, "scale") <- sapply(xz, attr, "scale")
   attr(x_out, "robust") <- sapply(xz, attr, "robust")[1]
+  class(x_out) <- c("dw_transformer", class(x_out))
 
   x_out
 }
