@@ -1,5 +1,5 @@
 test_that("adjust multilevel", {
-  skip_if_not_installed("lme4")
+  skip_if_not_or_load_if_installed("lme4")
   adj <- adjust(iris[c("Sepal.Length", "Species")], multilevel = TRUE, bayesian = FALSE)
   expect_equal(
     head(adj$Sepal.Length),
@@ -19,11 +19,11 @@ test_that("adjust", {
 
 # select helpers ------------------------------
 test_that("adjust regex", {
-  expect_equal(
+  expect_identical(
     adjust(mtcars, select = "pg", regex = TRUE),
     adjust(mtcars, select = "mpg")
   )
-  expect_equal(
+  expect_identical(
     adjust(mtcars, select = "pg$", regex = TRUE),
     adjust(mtcars, select = "mpg")
   )
