@@ -1,7 +1,7 @@
 # numeric ---------------------------------------
 
 test_that("describe_distribution - numeric: works with basic numeric vector", {
-  skip_if_not_or_load_if_installed("bayestestR")
+  skip_if_not_installed("bayestestR")
 
   x <- describe_distribution(mtcars$mpg)
   expect_equal(dim(x), c(1, 9))
@@ -9,7 +9,7 @@ test_that("describe_distribution - numeric: works with basic numeric vector", {
 })
 
 test_that("describe_distribution - numeric: correctly handles missing values", {
-  skip_if_not_or_load_if_installed("bayestestR")
+  skip_if_not_installed("bayestestR")
 
   no_missing <- describe_distribution(mtcars$mpg)
   test <- mtcars$mpg
@@ -21,7 +21,7 @@ test_that("describe_distribution - numeric: correctly handles missing values", {
 })
 
 test_that("describe_distribution - numeric: works with quartiles", {
-  skip_if_not_or_load_if_installed("bayestestR")
+  skip_if_not_installed("bayestestR")
 
   x <- describe_distribution(mtcars$mpg, quartiles = TRUE)
   expect_equal(dim(x), c(1, 11))
@@ -30,7 +30,7 @@ test_that("describe_distribution - numeric: works with quartiles", {
 })
 
 test_that("describe_distribution - numeric: works with range", {
-  skip_if_not_or_load_if_installed("bayestestR")
+  skip_if_not_installed("bayestestR")
 
   x <- describe_distribution(mtcars$mpg, range = FALSE)
   expect_equal(dim(x), c(1, 7))
@@ -39,7 +39,7 @@ test_that("describe_distribution - numeric: works with range", {
 })
 
 test_that("describe_distribution - NULL for date", {
-  skip_if_not_or_load_if_installed("bayestestR")
+  skip_if_not_installed("bayestestR")
 
   v <- as.Date(c("2022-01-01", "2022-01-02"))
   expect_warning(expect_null(describe_distribution(v)))
@@ -50,7 +50,7 @@ test_that("describe_distribution - NULL for date", {
 # data frame ---------------------------------------
 
 test_that("describe_distribution - data frame: works with basic data frame", {
-  skip_if_not_or_load_if_installed("bayestestR")
+  skip_if_not_installed("bayestestR")
 
   x <- describe_distribution(mtcars)
   expect_equal(dim(x), c(11, 10))
@@ -58,7 +58,7 @@ test_that("describe_distribution - data frame: works with basic data frame", {
 })
 
 test_that("describe_distribution - data frame: correctly handles missing values", {
-  skip_if_not_or_load_if_installed("bayestestR")
+  skip_if_not_installed("bayestestR")
 
   no_missing <- describe_distribution(mtcars)
   test <- mtcars
@@ -70,7 +70,7 @@ test_that("describe_distribution - data frame: correctly handles missing values"
 })
 
 test_that("describe_distribution - data frame: works with quartiles", {
-  skip_if_not_or_load_if_installed("bayestestR")
+  skip_if_not_installed("bayestestR")
 
   x <- describe_distribution(mtcars, quartiles = TRUE)
   expect_equal(dim(x), c(11, 12))
@@ -79,7 +79,7 @@ test_that("describe_distribution - data frame: works with quartiles", {
 })
 
 test_that("describe_distribution - data frame: works with range", {
-  skip_if_not_or_load_if_installed("bayestestR")
+  skip_if_not_installed("bayestestR")
 
   x <- describe_distribution(mtcars, range = FALSE)
   expect_equal(dim(x), c(11, 8))
@@ -92,7 +92,7 @@ test_that("describe_distribution - data frame: works with range", {
 # factor ---------------------------------------
 
 test_that("describe_distribution - factor", {
-  skip_if_not_or_load_if_installed("bayestestR")
+  skip_if_not_installed("bayestestR")
 
   expect_snapshot(describe_distribution(factor(substring("statistics", 1:10, 1:10))))
 })
@@ -102,7 +102,7 @@ test_that("describe_distribution - factor", {
 # character ---------------------------------------
 
 test_that("describe_distribution - character", {
-  skip_if_not_or_load_if_installed("bayestestR")
+  skip_if_not_installed("bayestestR")
 
   expect_snapshot(describe_distribution(as.character(ToothGrowth$supp)))
 })
@@ -112,7 +112,7 @@ test_that("describe_distribution - character", {
 # list ---------------------------------------
 
 test_that("describe_distribution - list: works with basic list", {
-  skip_if_not_or_load_if_installed("bayestestR")
+  skip_if_not_installed("bayestestR")
 
   x <- list(mtcars$mpg, mtcars$cyl)
   stored <- describe_distribution(x)
@@ -131,7 +131,7 @@ test_that("describe_distribution - list: works with basic list", {
 })
 
 test_that("describe_distribution - list: works with include_factors", {
-  skip_if_not_or_load_if_installed("bayestestR")
+  skip_if_not_installed("bayestestR")
 
   x1 <- describe_distribution(list(mtcars$mpg, factor(mtcars$cyl)))
   y <- describe_distribution(list(mtcars$mpg))
@@ -151,7 +151,7 @@ test_that("describe_distribution - list: works with include_factors", {
 })
 
 test_that("describe_distribution - list: correctly removes character elements", {
-  skip_if_not_or_load_if_installed("bayestestR")
+  skip_if_not_installed("bayestestR")
 
   x <- describe_distribution(list(mtcars$mpg, "something"))
   y <- describe_distribution(list(mtcars$mpg))
@@ -159,7 +159,7 @@ test_that("describe_distribution - list: correctly removes character elements",
 })
 
 test_that("describe_distribution - list: correctly handles variable names", {
-  skip_if_not_or_load_if_installed("bayestestR")
+  skip_if_not_installed("bayestestR")
 
   x <- list(mtcars$mpg, mtcars$cyl)
   stored <- describe_distribution(x)
@@ -174,7 +174,7 @@ test_that("describe_distribution - list: correctly handles variable names", {
 })
 
 test_that("describe_distribution - list: correctly handles missing values", {
-  skip_if_not_or_load_if_installed("bayestestR")
+  skip_if_not_installed("bayestestR")
 
   no_missing <- describe_distribution(list(mtcars$mpg, mtcars$cyl))
   test <- mtcars$mpg
@@ -188,7 +188,7 @@ test_that("describe_distribution - list: correctly handles missing values", {
 })
 
 test_that("describe_distribution - list: works with quartiles", {
-  skip_if_not_or_load_if_installed("bayestestR")
+  skip_if_not_installed("bayestestR")
 
   x <- describe_distribution(list(mtcars$mpg, mtcars$cyl), quartiles = TRUE)
   expect_equal(dim(x), c(2, 12))
@@ -197,7 +197,7 @@ test_that("describe_distribution - list: works with quartiles", {
 })
 
 test_that("describe_distribution - list: works with range", {
-  skip_if_not_or_load_if_installed("bayestestR")
+  skip_if_not_installed("bayestestR")
 
   x <- describe_distribution(list(mtcars$mpg, mtcars$cyl), range = FALSE)
   expect_equal(dim(x), c(2, 8))
@@ -210,7 +210,7 @@ test_that("describe_distribution - list: works with range", {
 # select ----------------------
 
 test_that("describe_distribution - select", {
-  skip_if_not_or_load_if_installed("bayestestR")
+  skip_if_not_installed("bayestestR")
 
   data(iris)
   out <- describe_distribution(iris, select = starts_with("Petal"))
@@ -224,7 +224,7 @@ test_that("describe_distribution - select", {
 # select and grouped df ----------------------
 
 test_that("describe_distribution - grouped df", {
-  skip_if_not_or_load_if_installed("bayestestR")
+  skip_if_not_installed("bayestestR")
 
   data(iris)
   x <- data_group(iris, Species)
@@ -247,7 +247,7 @@ test_that("describe_distribution - grouped df", {
 # distribution_mode --------------------------
 
 test_that("distribution_mode works as expected", {
-  skip_if_not_or_load_if_installed("bayestestR")
+  skip_if_not_installed("bayestestR")
 
   # atomic vector
   expect_equal(distribution_mode(c(1, 2, 3, 3, 4, 5)), 3)
@@ -266,7 +266,7 @@ test_that("distribution_mode works as expected", {
 
 # select helpers ------------------------------
 test_that("describe_distribution regex", {
-  skip_if_not_or_load_if_installed("bayestestR")
+  skip_if_not_installed("bayestestR")
 
   expect_equal(
     describe_distribution(mtcars, select = "pg", regex = TRUE),
