@@ -1,19 +1,17 @@
-suppressPackageStartupMessages(library(poorman, warn.conflicts = FALSE))
-
 test_that("ranktransform works with NAs", {
   x <- c(NA_real_, NA_real_)
-  expect_equal(ranktransform(x), x)
+  expect_identical(ranktransform(x), x)
 })
 
 test_that("ranktransform works with factors", {
   x <- factor(c("apple", "bear", "banana", "dear"))
-  expect_equal(ranktransform(x), x)
+  expect_identical(ranktransform(x), x)
 })
 
 test_that("ranktransform works with unique value vectors", {
   x <- c(1L, 1L, 1L)
 
-  expect_equal(suppressWarnings(ranktransform(x)), x)
+  expect_identical(suppressWarnings(ranktransform(x)), x)
 
   expect_warning(
     ranktransform(x),
@@ -24,11 +22,11 @@ test_that("ranktransform works with unique value vectors", {
 test_that("ranktransform works with two unique value vectors", {
   x <- c(1L, 1L, 1L, 2L, 2L, 2L)
 
-  expect_equal(suppressWarnings(ranktransform(x)), c(2, 2, 2, 5, 5, 5))
+  expect_identical(suppressWarnings(ranktransform(x)), c(2, 2, 2, 5, 5, 5))
 
   expect_warning(
     ranktransform(x),
-    "Variable `x` contains only two different values. Consider converting it to a factor."
+    "Consider converting it"
   )
 })
 
@@ -38,8 +36,8 @@ test_that("signed rank works as expected", {
   sr <- ranktransform(x, sign = TRUE)
   r <- ranktransform(x, sign = FALSE)
 
-  expect_equal(sr, x) # unchanged
-  expect_equal(r, c(2, 3, 1, 4))
+  expect_identical(sr, x) # unchanged
+  expect_identical(r, c(2, 3, 1, 4))
 
   x <- c(1, -2, -2, 4, 0, 3, -14, 0)
   expect_warning(ranktransform(x, sign = TRUE))
@@ -65,11 +63,14 @@ value2 <- sample(1:20, 9, replace = TRUE)
 test_df <- data.frame(
   id = rep(c("A", "B", "C"), each = 3),
   value1 = value1,
-  value2 = value2
+  value2 = value2,
+  stringsAsFactors = FALSE
 )
 
 test_that("ranktransform works with data frames (grouped data)", {
-  expect_equal(
+  skip_if_not_or_load_if_installed("poorman")
+
+  expect_identical(
     test_df %>%
       group_by(id) %>%
       ranktransform(exclude = "id") %>%
@@ -77,7 +78,8 @@ test_that("ranktransform works with data frames (grouped data)", {
     data.frame(
       id = rep(c("A", "B", "C"), each = 3),
       value1 = c(2, 3, 1, 1, 2, 3, 2, 1, 3),
-      value2 = c(3, 2, 1, 1, 3, 2, 2, 3, 1)
+      value2 = c(3, 2, 1, 1, 3, 2, 2, 3, 1),
+      stringsAsFactors = FALSE
     )
   )
 })
@@ -92,11 +94,14 @@ value2 <- sample(c(1:15, NA), 9, replace = TRUE)
 test_df <- data.frame(
   id = rep(c("A", "B", "C"), each = 3),
   value1 = value1,
-  value2 = value2
+  value2 = value2,
+  stringsAsFactors = FALSE
 )
 
 test_that("ranktransform works with data frames containing NAs (grouped data)", {
-  expect_equal(
+  skip_if_not_or_load_if_installed("poorman")
+
+  expect_identical(
     test_df %>%
       group_by(id) %>%
       ranktransform(exclude = "id") %>%
@@ -104,14 +109,15 @@ test_that("ranktransform works with data frames containing NAs (grouped data)",
     data.frame(
       id = rep(c("A", "B", "C"), each = 3),
       value1 = c(2, NA, 1, 1, 3, 2, 2, NA, 1),
-      value2 = c(3, 1, 2, NA, 2, 1, 3, 1, 2)
+      value2 = c(3, 1, 2, NA, 2, 1, 3, 1, 2),
+      stringsAsFactors = FALSE
     )
   )
 })
 
 # select helpers ------------------------------
 test_that("ranktransform regex", {
-  expect_equal(
+  expect_identical(
     ranktransform(mtcars, select = "pg", regex = TRUE),
     ranktransform(mtcars, select = "mpg")
   )
